/* 
 * linux/include/linux/bossa.h 
 *   Copyright (C) 2004 EMN, DIKU. All rights reserved.
 *   Ecole des Mines de Nantes, University of Copenhagen.
 *
 * This file describes the interface defined by the RTS and exported to
 * both policies and the kernel.
 *
 */

/*******************************************************
 * various structures :
 *
 *     bossa_struct : representation of a process
 *     event_struct : representation of an event
 *
 *******************************************************/

struct process_struct;
struct event_struct;

#ifndef PROTOCOL_PROCESS_STRUCT
#define PROTOCOL_PROCESS_STRUCT struct bossa_struct
#endif

/*******************************************************
 * next_list : 
 *
 *     This is the list of virtual/process schedulers managing the
 *     associated process
 *
 *******************************************************/

struct next_list_struct {
  /* the current virtual/process scheduler */
  PROTOCOL_SCHEDULER_STRUCT *sched;
  /* next process in the next list */
  struct next_list_struct *next;
  /* previous process in the next list */
  struct next_list_struct *prev;
};

/*******************************************************
 * bossa_struct : 
 *
 *     used to define Bossa processes
 *     every process scheduler must define a structure for child processes
 *     that begins with this format
 *
 *    *attr points to the default process atributes (pid, memory context)
 *
 *******************************************************/

struct bossa_struct {
  /* default attributes for Bossa */
  /* next and previous processes in the current bossa queue */
  struct list_head list_info;
  /* list of virtual schedulers on the way to this process */
  struct next_list_struct *next_list;
  /* process state */
  int state;
};

/*******************************************************
 *
 * The current state of the scheduling hierarchy
 *
 *******************************************************/

enum SchedState {
  RUNNING    = 1<<2,
  READY      = 1<<3,
  BLOCKED    = 1<<4
};

extern struct bossa_struct *rts_idle_process;  // System wide idle
extern enum SchedState root_s_state;           // state of the root scheduler
extern spinlock_t bossa_scheduler_lock;



#ifdef IN_POLICY
#include "bossa_policy_rts.h"
#include "bossa_policy_kernel.h"
#else
#ifdef IN_RTS
#include "bossa_rts_kernel.h"
#include "bossa_policy_rts.h"
#else
#include "bossa_policy_kernel.h"
#include "bossa_rts_kernel.h"
#endif
#endif
