/*******************************************************
 * 
 * Bossa events
 *
 *******************************************************/

/*
 * Bossa events are structured in six top level classes:
 *
 *  event       mask              description
 * =======   ============      =====================
 * BLOCK     0x01........      blocking events
 * UNBLOCK   0x02........      unblocking events
 * YIELD     0x03........      process-related events
 * SYSTEM    0x04........      system events
 * PROCESS   0x05........      process-related events
 * BOSSA     0x06........      Bossa run-time events
 *
 */

#ifndef BOSSA_EVENTS
#define BOSSA_EVENTS


#define MAIN_REST_INIT                           	 0x00000101
#define MAIN_START_KERNEL                        	 0x00000102

#define KERNEL_SCHED_SCHEDULE_TIMEOUT            	 0x00000201
#define KERNEL_SCHED_SCHEDULE                    	 0x00000202
#define KERNEL_SCHED_WAIT_FOR_COMPLETION         	 0x00000203
#define KERNEL_SCHED_INTERRUPTIBLE_SLEEP_ON      	 0x00000204
#define KERNEL_SCHED_INTERRUPTIBLE_SLEEP_ON_TIMEOUT 	 0x00000205
#define KERNEL_SCHED_SLEEP_ON                    	 0x00000206
#define KERNEL_SCHED_SLEEP_ON_TIMEOUT            	 0x00000207
#define KERNEL_SCHED_SYS_NICE                    	 0x00000208
#define KERNEL_SCHED_YIELD                       	 0x00000209
#define KERNEL_SCHED___COND_RESCHED              	 0x0000020a
#define KERNEL_SCHED_WAKE_UP_PROCESS             	 0x0000020b
#define KERNEL_SCHED___WAKE_UP_COMMON            	 0x0000020c

#define KERNEL_FORK_DO_FORK                      	 0x00000301

#define KERNEL_PRINTK_DO_SYSLOG                  	 0x00000401
#define KERNEL_PRINTK_CONSOLE_CONDITIONAL_SCHEDULE 	 0x00000402

#define KERNEL_EXIT_RELEASE_TASK                 	 0x00000501
#define KERNEL_EXIT_DO_EXIT                      	 0x00000502
#define KERNEL_EXIT_SYS_WAIT4                    	 0x00000503

#define KERNEL_SOFTIRQ_KSOFTIRQD                 	 0x00000601

#define KERNEL_TIMER_UPDATE_PROCESS_TIMES        	 0x00000701
#define KERNEL_TIMER_UPDATE_TIMES                	 0x00000702

#define KERNEL_SIGNAL_SYS_RT_SIGTIMEDWAIT        	 0x00000801

#define KERNEL_CONTEXT_CONTEXT_THREAD            	 0x00000901
#define KERNEL_CONTEXT_FLUSH_SCHEDULED_TASKS     	 0x00000902

#define KERNEL_POSIX_TIMERS_DO_CLOCK_NANOSLEEP   	 0x00000a01

#define DRIVERS_ACPI_OS_ACPI_OS_SLEEP            	 0x00000b01
#define DRIVERS_ACPI_OS_ACPI_OS_WAIT_SEMAPHORE   	 0x00000b02

#define DRIVERS_ATM_ENI_CLOSE_RX                 	 0x00000c01
#define DRIVERS_ATM_ENI_CLOSE_TX                 	 0x00000c02
#define DRIVERS_ATM_NICSTAR_NS_CLOSE             	 0x00000c03
#define DRIVERS_ATM_IDT77252_IDT77252_CLOSE      	 0x00000c04
#define DRIVERS_ATM_ATMTCP_ATMTCP_SEND_CONTROL   	 0x00000c05
#define DRIVERS_ATM_FIRESTREAM_SUBMIT_QENTRY     	 0x00000c06
#define DRIVERS_ATM_FIRESTREAM_FS_INIT           	 0x00000c07
#define DRIVERS_ATM_LANAI_LANAI_SHUTDOWN_TX_VCI  	 0x00000c08

#define DRIVERS_BLOCK_PARIDE_PARIDE_PI_CLAIM     	 0x00000d01
#define DRIVERS_BLOCK_PARIDE_PD_PD_OPEN          	 0x00000d02
#define DRIVERS_BLOCK_PARIDE_PCD_PCD_SLEEP       	 0x00000d03
#define DRIVERS_BLOCK_PARIDE_PF_PF_SLEEP         	 0x00000d04
#define DRIVERS_BLOCK_PARIDE_PT_PT_SLEEP         	 0x00000d05
#define DRIVERS_BLOCK_PARIDE_PG_PG_SLEEP         	 0x00000d06

#define DRIVERS_BLOCK_LL_RW_BLK___GET_REQUEST_WAIT 	 0x00000e01

#define DRIVERS_BLOCK_FLOPPY__LOCK_FDC           	 0x00000f01
#define DRIVERS_BLOCK_FLOPPY_WAIT_TIL_DONE       	 0x00000f02

#define DRIVERS_BLOCK_LOOP_LOOP_GET_BUFFER       	 0x00001001

#define DRIVERS_BLOCK_XD_XD_WAITPORT             	 0x00001101
#define DRIVERS_BLOCK_XD_XD_INITDRIVES           	 0x00001102
#define DRIVERS_BLOCK_XD_XD_WD_INIT_CONTROLLER   	 0x00001103
#define DRIVERS_BLOCK_XD_XD_XEBEC_INIT_CONTROLLER 	 0x00001104

#define DRIVERS_BLOCK_CPQARRAY_IDA_CTLR_IOCTL    	 0x00001201
#define DRIVERS_BLOCK_CPQARRAY_SENDCMD_WITHIRQ   	 0x00001202

#define DRIVERS_BLOCK_DAC960_DAC960_WAITFORCOMMAND 	 0x00001301
#define DRIVERS_BLOCK_DAC960_DAC960_USERIOCTL    	 0x00001302

#define DRIVERS_BLUETOOTH_HCI_USB_WAIT_MS        	 0x00001401
#define DRIVERS_BLUETOOTH_HCI_VHCI_HCI_VHCI_CHR_READ 	 0x00001402
#define DRIVERS_BLUETOOTH_DTL1_CS_DTL1_OPEN      	 0x00001403
#define DRIVERS_BLUETOOTH_BT3C_CS_BT3C_OPEN      	 0x00001404
#define DRIVERS_BLUETOOTH_BLUECARD_CS_BLUECARD_OPEN 	 0x00001405

#define DRIVERS_CDROM_CDU31A_SONY_SLEEP          	 0x00001501
#define DRIVERS_CDROM_CDU31A_RESTART_ON_ERROR    	 0x00001502
#define DRIVERS_CDROM_CDU31A_DO_SONY_CD_CMD      	 0x00001503
#define DRIVERS_CDROM_MCD_MCD_OPEN               	 0x00001504
#define DRIVERS_CDROM_SBPCD_SBP_SLEEP            	 0x00001505
#define DRIVERS_CDROM_SBPCD2_SBP_SLEEP           	 0x00001506
#define DRIVERS_CDROM_SBPCD3_SBP_SLEEP           	 0x00001507
#define DRIVERS_CDROM_SBPCD4_SBP_SLEEP           	 0x00001508
#define DRIVERS_CDROM_SONYCD535_SONY_SLEEP       	 0x00001509
#define DRIVERS_CDROM_SONYCD535_DO_CDU535_REQUEST 	 0x0000150a
#define DRIVERS_CDROM_SONYCD535_SONY535_INIT     	 0x0000150b

#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_DMA_PRIORITY 	 0x00001601
#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_DMA_SEND_BUFFERS 	 0x00001602
#define DRIVERS_CHAR_DRM_4_0_GAMMA_DMA_GAMMA_LOCK 	 0x00001603
#define DRIVERS_CHAR_DRM_4_0_CONTEXT_DRM_RMCTX   	 0x00001604
#define DRIVERS_CHAR_DRM_4_0_LISTS_DRM_FREELIST_GET 	 0x00001605
#define DRIVERS_CHAR_DRM_4_0_LOCK_DRM_FLUSH_QUEUE 	 0x00001606
#define DRIVERS_CHAR_DRM_4_0_DMA_DRM_DMA_ENQUEUE 	 0x00001607
#define DRIVERS_CHAR_DRM_4_0_R128_DRV_R128_LOCK  	 0x00001608
#define DRIVERS_CHAR_DRM_4_0_RADEON_DRV_RADEON_LOCK 	 0x00001609
#define DRIVERS_CHAR_DRM_4_0_MGA_DRV_MGA_RELEASE 	 0x0000160a
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_FREELIST_GET 	 0x0000160b
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_ADVANCE_PRIMARY 	 0x0000160c
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_FLUSH_QUEUE 	 0x0000160d
#define DRIVERS_CHAR_DRM_4_0_MGA_DMA_MGA_LOCK    	 0x0000160e
#define DRIVERS_CHAR_DRM_4_0_I810_DRV_I810_RELEASE 	 0x0000160f
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_DMA_QUIESCENT 	 0x00001610
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_FLUSH_QUEUE 	 0x00001611
#define DRIVERS_CHAR_DRM_4_0_I810_DMA_I810_LOCK  	 0x00001612

#define DRIVERS_CHAR_FTAPE_LOWLEVEL_FDC_IO_FDC_INTERRUPT_WAIT 	 0x00001701
#define DRIVERS_CHAR_FTAPE_LOWLEVEL_FTAPE_IO_FTAPE_SLEEP 	 0x00001702
#define DRIVERS_CHAR_FTAPE_ZFTAPE_ZFTAPE_BUFFERS_ZFT_KMALLOC 	 0x00001703

#define DRIVERS_CHAR_JOYSTICK_GAMEPORT_WAIT_MS   	 0x00001801
#define DRIVERS_CHAR_JOYSTICK_SERPORT_SERPORT_LDISC_READ 	 0x00001802
#define DRIVERS_CHAR_JOYSTICK_NS558_WAIT_MS      	 0x00001803
#define DRIVERS_CHAR_JOYSTICK_LIGHTNING_WAIT_MS  	 0x00001804
#define DRIVERS_CHAR_JOYSTICK_PCIGAME_WAIT_MS    	 0x00001805
#define DRIVERS_CHAR_JOYSTICK_CS461X_WAIT_MS     	 0x00001806
#define DRIVERS_CHAR_JOYSTICK_EMU10K1_GP_WAIT_MS 	 0x00001807
#define DRIVERS_CHAR_JOYSTICK_IFORCE_WAIT_MS     	 0x00001808
#define DRIVERS_CHAR_JOYSTICK_IFORCE_SEND_PACKET 	 0x00001809
#define DRIVERS_CHAR_JOYSTICK_IFORCE_GET_ID_PACKET 	 0x0000180a
#define DRIVERS_CHAR_JOYSTICK_ANALOG_WAIT_MS     	 0x0000180b
#define DRIVERS_CHAR_JOYSTICK_A3D_WAIT_MS        	 0x0000180c
#define DRIVERS_CHAR_JOYSTICK_ADI_WAIT_MS        	 0x0000180d
#define DRIVERS_CHAR_JOYSTICK_COBRA_WAIT_MS      	 0x0000180e
#define DRIVERS_CHAR_JOYSTICK_GF2K_WAIT_MS       	 0x0000180f
#define DRIVERS_CHAR_JOYSTICK_GRIP_WAIT_MS       	 0x00001810
#define DRIVERS_CHAR_JOYSTICK_INTERACT_WAIT_MS   	 0x00001811
#define DRIVERS_CHAR_JOYSTICK_TMDC_WAIT_MS       	 0x00001812
#define DRIVERS_CHAR_JOYSTICK_SIDEWINDER_WAIT_MS 	 0x00001813

#define DRIVERS_CHAR_MWAVE_3780I_PACEMSAACCESS   	 0x00001901

#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_WAIT_EVENTS 	 0x00001a01
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MODEM_INPUT_WAIT 	 0x00001a02
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MGSLPC_CLOSE 	 0x00001a03
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_MGSLPC_WAIT_UNTIL_SENT 	 0x00001a04
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_BLOCK_TIL_READY 	 0x00001a05
#define DRIVERS_CHAR_PCMCIA_SYNCLINK_CS_IRQ_TEST 	 0x00001a06

#define DRIVERS_CHAR_RIO_RIO_LINUX_RIODELAY      	 0x00001b01
#define DRIVERS_CHAR_RIO_RIO_LINUX_RIODELAY_NI   	 0x00001b02

#define DRIVERS_CHAR_MEM_READ_ZERO_PAGEALIGNED   	 0x00001c01

#define DRIVERS_CHAR_TTY_IO_DO_TTY_WRITE         	 0x00001d01
#define DRIVERS_CHAR_TTY_IO_RELEASE_DEV          	 0x00001d02
#define DRIVERS_CHAR_TTY_IO_TTY_OPEN             	 0x00001d03
#define DRIVERS_CHAR_TTY_IO_SEND_BREAK           	 0x00001d04

#define DRIVERS_CHAR_N_TTY_READ_CHAN             	 0x00001e01
#define DRIVERS_CHAR_N_TTY_WRITE_CHAN            	 0x00001e02

#define DRIVERS_CHAR_TTY_IOCTL_TTY_WAIT_UNTIL_SENT 	 0x00001f01

#define DRIVERS_CHAR_RANDOM_EXTRACT_ENTROPY      	 0x00002001
#define DRIVERS_CHAR_RANDOM_RANDOM_READ          	 0x00002002

#define DRIVERS_CHAR_VT_VT_WAITACTIVE            	 0x00002101

#define DRIVERS_CHAR_SELECTION_PASTE_SELECTION   	 0x00002201

#define DRIVERS_CHAR_SERIAL_RS_CLOSE             	 0x00002301
#define DRIVERS_CHAR_SERIAL_RS_WAIT_UNTIL_SENT   	 0x00002302
#define DRIVERS_CHAR_SERIAL_BLOCK_TIL_READY      	 0x00002303
#define DRIVERS_CHAR_SERIAL_PCI_XIRCOM_FN        	 0x00002304

#define DRIVERS_CHAR_PC_KEYB_READ_AUX            	 0x00002401

#define DRIVERS_CHAR_ROCKET_BLOCK_TIL_READY      	 0x00002501
#define DRIVERS_CHAR_ROCKET_RP_CLOSE             	 0x00002502
#define DRIVERS_CHAR_ROCKET_RP_WAIT_UNTIL_SENT   	 0x00002503

#define DRIVERS_CHAR_MXSER_MXSER_CLOSE           	 0x00002601
#define DRIVERS_CHAR_MXSER_MXSER_BLOCK_TIL_READY 	 0x00002602
#define DRIVERS_CHAR_MXSER_MXSER_SEND_BREAK      	 0x00002603

#define DRIVERS_CHAR_MOXA_MOXA_CLOSE             	 0x00002701
#define DRIVERS_CHAR_MOXA_BLOCK_TILL_READY       	 0x00002702

#define DRIVERS_CHAR_EPCA_PC_CLOSE               	 0x00002801
#define DRIVERS_CHAR_EPCA_BLOCK_TIL_READY        	 0x00002802

#define DRIVERS_CHAR_CYCLADES_BLOCK_TIL_READY    	 0x00002901
#define DRIVERS_CHAR_CYCLADES_CY_WAIT_UNTIL_SENT 	 0x00002902
#define DRIVERS_CHAR_CYCLADES_CY_CLOSE           	 0x00002903

#define DRIVERS_CHAR_STALLION_STL_DELAY          	 0x00002a01

#define DRIVERS_CHAR_ISTALLION_STLI_DELAY        	 0x00002b01

#define DRIVERS_CHAR_RISCOM8_BLOCK_TIL_READY     	 0x00002c01
#define DRIVERS_CHAR_RISCOM8_RC_CLOSE            	 0x00002c02

#define DRIVERS_CHAR_ESP_RS_CLOSE                	 0x00002d01
#define DRIVERS_CHAR_ESP_RS_WAIT_UNTIL_SENT      	 0x00002d02
#define DRIVERS_CHAR_ESP_BLOCK_TIL_READY         	 0x00002d03

#define DRIVERS_CHAR_SYNCLINK_MGSL_WAIT_EVENT    	 0x00002e01
#define DRIVERS_CHAR_SYNCLINK_MODEM_INPUT_WAIT   	 0x00002e02
#define DRIVERS_CHAR_SYNCLINK_MGSL_CLOSE         	 0x00002e03
#define DRIVERS_CHAR_SYNCLINK_MGSL_WAIT_UNTIL_SENT 	 0x00002e04
#define DRIVERS_CHAR_SYNCLINK_BLOCK_TIL_READY    	 0x00002e05
#define DRIVERS_CHAR_SYNCLINK_MGSL_IRQ_TEST      	 0x00002e06

#define DRIVERS_CHAR_SYNCLINKMP_CLOSE            	 0x00002f01
#define DRIVERS_CHAR_SYNCLINKMP_WAIT_UNTIL_SENT  	 0x00002f02
#define DRIVERS_CHAR_SYNCLINKMP_WAIT_MGSL_EVENT  	 0x00002f03
#define DRIVERS_CHAR_SYNCLINKMP_MODEM_INPUT_WAIT 	 0x00002f04
#define DRIVERS_CHAR_SYNCLINKMP_BLOCK_TIL_READY  	 0x00002f05
#define DRIVERS_CHAR_SYNCLINKMP_IRQ_TEST         	 0x00002f06
#define DRIVERS_CHAR_SYNCLINKMP_LOOPBACK_TEST    	 0x00002f07

#define DRIVERS_CHAR_N_HDLC_N_HDLC_TTY_WRITE     	 0x00003001

#define DRIVERS_CHAR_SPECIALIX_BLOCK_TIL_READY   	 0x00003101
#define DRIVERS_CHAR_SPECIALIX_SX_CLOSE          	 0x00003102

#define DRIVERS_CHAR_SX_SX_CLOSE                 	 0x00003201

#define DRIVERS_CHAR_GENERIC_SERIAL_GS_WAIT_TX_FLUSHED 	 0x00003301
#define DRIVERS_CHAR_GENERIC_SERIAL_GS_BLOCK_TIL_READY 	 0x00003302
#define DRIVERS_CHAR_GENERIC_SERIAL_GS_CLOSE     	 0x00003303

#define DRIVERS_CHAR_LP_LP_WRITE                 	 0x00003401
#define DRIVERS_CHAR_LP_LP_READ                  	 0x00003402

#define DRIVERS_CHAR_BUSMOUSE_BUSMOUSE_READ      	 0x00003501

#define DRIVERS_CHAR_DTLK_DTLK_CLEANUP           	 0x00003601
#define DRIVERS_CHAR_DTLK_DTLK_DELAY             	 0x00003602

#define DRIVERS_CHAR_N_R3964_R3964_READ          	 0x00003701

#define DRIVERS_CHAR_APPLICOM_AC_WRITE           	 0x00003801
#define DRIVERS_CHAR_APPLICOM_AC_READ            	 0x00003802

#define DRIVERS_CHAR_SONYPI_SONYPI_CAMERA_ON     	 0x00003901
#define DRIVERS_CHAR_SONYPI_SONYPI_MISC_READ     	 0x00003902

#define DRIVERS_CHAR_QPMOUSE_POLL_QP_STATUS      	 0x00003a01
#define DRIVERS_CHAR_QPMOUSE_READ_QP             	 0x00003a02

#define DRIVERS_CHAR_MK712_MK712_READ            	 0x00003b01

#define DRIVERS_CHAR_RTC_RTC_READ                	 0x00003c01

#define DRIVERS_CHAR_I810_RNG_RNG_DEV_READ       	 0x00003d01

#define DRIVERS_CHAR_AMD768_RNG_RNG_DEV_READ     	 0x00003e01

#define DRIVERS_CHAR_AMD76X_PM_AMD76X_PM_CLEANUP 	 0x00003f01

#define DRIVERS_CHAR_TPQIC02_WAIT_FOR_READY      	 0x00004001
#define DRIVERS_CHAR_TPQIC02_RDSTATUS            	 0x00004002
#define DRIVERS_CHAR_TPQIC02_DO_IOCTL_CMD        	 0x00004003

#define DRIVERS_CHAR_PPDEV_PP_READ               	 0x00004101
#define DRIVERS_CHAR_PPDEV_PP_WRITE              	 0x00004102

#define DRIVERS_CHAR_PCWD_CHECK_ISA_CARD         	 0x00004201

#define DRIVERS_I2C_I2C_ALGO_BIT_SCLHI           	 0x00004301
#define DRIVERS_I2C_I2C_ALGO_PCF_PCF_SLEEP       	 0x00004302

#define DRIVERS_IDE_IDE_IDE_DELAY_50MS           	 0x00004401
#define DRIVERS_IDE_IDE_CS_IDE_CONFIG            	 0x00004402
#define DRIVERS_IDE_IDE_CD_CDROM_SLEEP           	 0x00004403
#define DRIVERS_IDE_IDE_TAPE_IDETAPE_WAIT_READY  	 0x00004404

#define DRIVERS_IEEE1394_NODEMGR_NODEMGR_READ_QUADLET 	 0x00004501
#define DRIVERS_IEEE1394_NODEMGR_READ_BUSINFO_BLOCK 	 0x00004502
#define DRIVERS_IEEE1394_NODEMGR_NODEMGR_NODE_PROBE 	 0x00004503
#define DRIVERS_IEEE1394_SBP2_SBP2UTIL_DOWN_TIMEOUT 	 0x00004504
#define DRIVERS_IEEE1394_DV1394_DV1394_WRITE     	 0x00004505
#define DRIVERS_IEEE1394_DV1394_DV1394_READ      	 0x00004506
#define DRIVERS_IEEE1394_DV1394_DV1394_IOCTL     	 0x00004507
#define DRIVERS_IEEE1394_AMDTP_OHCI1394_STOP_IT_CTX 	 0x00004508
#define DRIVERS_IEEE1394_AMDTP_STREAM_FREE       	 0x00004509
#define DRIVERS_IEEE1394_AMDTP_AMDTP_WRITE       	 0x0000450a

#define DRIVERS_INPUT_MOUSEDEV_MOUSEDEV_READ     	 0x00004601
#define DRIVERS_INPUT_JOYDEV_JOYDEV_READ         	 0x00004602
#define DRIVERS_INPUT_EVDEV_EVDEV_READ           	 0x00004603

#define DRIVERS_ISDN_ACT2000_ACT2000_ISA_ACT2000_ISA_DELAY 	 0x00004701
#define DRIVERS_ISDN_AVMB1_KCAPI_OLD_CAPI_MANUFACTURER 	 0x00004702
#define DRIVERS_ISDN_HISAX_CONFIG_INIT_CARD      	 0x00004703
#define DRIVERS_ISDN_HISAX_ASUSCOM_RESET_ASUSCOM 	 0x00004704
#define DRIVERS_ISDN_HISAX_AVM_PCI_RESET_AVMPCIPNP 	 0x00004705
#define DRIVERS_ISDN_HISAX_BKM_A4T_RESET_BKM     	 0x00004706
#define DRIVERS_ISDN_HISAX_BKM_A8_RESET_BKM      	 0x00004707
#define DRIVERS_ISDN_HISAX_DIVA_RESET_DIVA       	 0x00004708
#define DRIVERS_ISDN_HISAX_ELSA_RESET_ELSA       	 0x00004709
#define DRIVERS_ISDN_HISAX_ELSA_ELSA_CARD_MSG    	 0x0000470a
#define DRIVERS_ISDN_HISAX_ENTERNOW_PCI_RESET_ENPCI 	 0x0000470b
#define DRIVERS_ISDN_HISAX_ENTERNOW_PCI_SETUP_ENTERNOW_PCI 	 0x0000470c
#define DRIVERS_ISDN_HISAX_HFC_PCI_RELEASE_IO_HFCPCI 	 0x0000470d
#define DRIVERS_ISDN_HISAX_HFC_PCI_RESET_HFCPCI  	 0x0000470e
#define DRIVERS_ISDN_HISAX_HFC_PCI_HFCPCI_CARD_MSG 	 0x0000470f
#define DRIVERS_ISDN_HISAX_HFC_SX_RELEASE_IO_HFCSX 	 0x00004710
#define DRIVERS_ISDN_HISAX_HFC_SX_RESET_HFCSX    	 0x00004711
#define DRIVERS_ISDN_HISAX_HFC_SX_HFCSX_CARD_MSG 	 0x00004712
#define DRIVERS_ISDN_HISAX_HFCSCARD_RESET_HFCS   	 0x00004713
#define DRIVERS_ISDN_HISAX_HFCSCARD_HFCS_CARD_MSG 	 0x00004714
#define DRIVERS_ISDN_HISAX_ISURF_RESET_ISURF     	 0x00004715
#define DRIVERS_ISDN_HISAX_NJ_S_RESET_NETJET_S   	 0x00004716
#define DRIVERS_ISDN_HISAX_NJ_S_SETUP_NETJET_S   	 0x00004717
#define DRIVERS_ISDN_HISAX_NJ_U_RESET_NETJET_U   	 0x00004718
#define DRIVERS_ISDN_HISAX_NJ_U_SETUP_NETJET_U   	 0x00004719
#define DRIVERS_ISDN_HISAX_SAPHIR_SAPHIR_RESET   	 0x0000471a
#define DRIVERS_ISDN_HISAX_SEDLBAUER_RESET_SEDLBAUER 	 0x0000471b
#define DRIVERS_ISDN_HISAX_SEDLBAUER_SETUP_SEDLBAUER 	 0x0000471c
#define DRIVERS_ISDN_HISAX_SPORTSTER_RESET_SPORTSTER 	 0x0000471d
#define DRIVERS_ISDN_HISAX_TELEINT_RESET_TELEINT 	 0x0000471e
#define DRIVERS_ISDN_HISAX_W6692_RESETW6692      	 0x0000471f
#define DRIVERS_ISDN_HISAX_ST5481_INIT_WAIT_MS   	 0x00004720
#define DRIVERS_ISDN_HISAX_ST5481_USB_WAIT_MS    	 0x00004721
#define DRIVERS_ISDN_HISAX_ST5481_D_WAIT_MS      	 0x00004722
#define DRIVERS_ISDN_HISAX_ST5481_B_WAIT_MS      	 0x00004723
#define DRIVERS_ISDN_HISAX_HISAX_FCPCIPNP_FCPCI_INIT 	 0x00004724
#define DRIVERS_ISDN_HISAX_HISAX_FCPCIPNP_FCPCIPNP_SETUP 	 0x00004725
#define DRIVERS_ISDN_ICN_ICN_ICN_CHECK_LOADER    	 0x00004726
#define DRIVERS_ISDN_ICN_ICN_ICN_LOADPROTO       	 0x00004727
#define DRIVERS_ISDN_ICN_ICN_ICN_COMMAND         	 0x00004728
#define DRIVERS_ISDN_ISDNLOOP_ISDNLOOP_ISDNLOOP_COMMAND 	 0x00004729
#define DRIVERS_ISDN_SC_INIT_SC_INIT             	 0x0000472a
#define DRIVERS_ISDN_SC_INIT_IDENTIFY_BOARD      	 0x0000472b
#define DRIVERS_ISDN_SC_MESSAGE_SEND_AND_RECEIVE 	 0x0000472c
#define DRIVERS_ISDN_TPAM_TPAM_COMMANDS_TPAM_COMMAND_IOCTL_DSPRUN 	 0x0000472d
#define DRIVERS_ISDN_ISDN_TTY_ISDN_TTY_BLOCK_TIL_READY 	 0x0000472e
#define DRIVERS_ISDN_ISDN_TTY_ISDN_TTY_CLOSE     	 0x0000472f

#define DRIVERS_MD_RAID1_RAID1_ALLOC_BH          	 0x00004801
#define DRIVERS_MD_RAID1_RAID1_ALLOC_R1BH        	 0x00004802
#define DRIVERS_MD_RAID1_RAID1_ALLOC_BUF         	 0x00004803
#define DRIVERS_MD_RAID1_RAID1_MAKE_REQUEST      	 0x00004804
#define DRIVERS_MD_RAID1_CLOSE_SYNC              	 0x00004805
#define DRIVERS_MD_RAID1_RAID1_SYNC_REQUEST      	 0x00004806
#define DRIVERS_MD_RAID5_GET_ACTIVE_STRIPE       	 0x00004807
#define DRIVERS_MD_MULTIPATH_MULTIPATH_ALLOC_MPBH 	 0x00004808
#define DRIVERS_MD_MD_FREE_MDDEV                 	 0x00004809
#define DRIVERS_MD_MD_MD_THREAD                  	 0x0000480a
#define DRIVERS_MD_MD_MD_DO_SYNC                 	 0x0000480b
#define DRIVERS_MD_LVM_LVM_DO_VG_REMOVE          	 0x0000480c

#define DRIVERS_MEDIA_RADIO_RADIO_SF16FMI_FMI_SETFREQ 	 0x00004901
#define DRIVERS_MEDIA_RADIO_RADIO_SF16FMI_FMI_GETSIGSTR 	 0x00004902
#define DRIVERS_MEDIA_RADIO_RADIO_MAXIRADIO_SLEEP_125MS 	 0x00004903
#define DRIVERS_MEDIA_RADIO_RADIO_AIMSLAB_SLEEP_DELAY 	 0x00004904
#define DRIVERS_MEDIA_RADIO_RADIO_ZOLTRIX_SLEEP_DELAY 	 0x00004905
#define DRIVERS_MEDIA_RADIO_MIROPCM20_RDS_RDS_F_READ 	 0x00004906
#define DRIVERS_MEDIA_RADIO_RADIO_MAESTRO_SLEEP_125MS 	 0x00004907
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_READ 	 0x00004908
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_WRITE 	 0x00004909
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3400C_THREAD 	 0x0000490a
#define DRIVERS_MEDIA_VIDEO_MSP3400_MSP3410D_THREAD 	 0x0000490b
#define DRIVERS_MEDIA_VIDEO_SAA5249_JDELAY       	 0x0000490c
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QCAM_AWAIT_READY1 	 0x0000490d
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QCAM_AWAIT_READY2 	 0x0000490e
#define DRIVERS_MEDIA_VIDEO_C_QCAM_QC_CAPTURE    	 0x0000490f
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_CALIBRATE 	 0x00004910
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_WAITHAND  	 0x00004911
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_WAITHAND2 	 0x00004912
#define DRIVERS_MEDIA_VIDEO_BW_QCAM_QC_CAPTURE   	 0x00004913
#define DRIVERS_MEDIA_VIDEO_ZR36067_ZR36057_ENABLE_JPG 	 0x00004914
#define DRIVERS_MEDIA_VIDEO_ZR36067_DO_ZORAN_IOCTL 	 0x00004915
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CWIPE      	 0x00004916
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CREAD      	 0x00004917
#define DRIVERS_MEDIA_VIDEO_STRADIS_I2CWRITE     	 0x00004918
#define DRIVERS_MEDIA_VIDEO_STRADIS_IBM_SEND_COMMAND 	 0x00004919
#define DRIVERS_MEDIA_VIDEO_STRADIS_INITIALIZE_CS4341 	 0x0000491a
#define DRIVERS_MEDIA_VIDEO_STRADIS_INITIALIZE_FPGA 	 0x0000491b
#define DRIVERS_MEDIA_VIDEO_CPIA_FETCH_FRAME     	 0x0000491c
#define DRIVERS_MEDIA_VIDEO_CPIA_USB_WAIT_MS     	 0x0000491d
#define DRIVERS_MEDIA_VIDEO_MEYE_WAIT_MS         	 0x0000491e
#define DRIVERS_MEDIA_VIDEO_MEYE_MEYE_DO_IOCTL   	 0x0000491f
#define DRIVERS_MEDIA_VIDEO_TUNER_3036_SET_TV_FREQ 	 0x00004920
#define DRIVERS_MEDIA_VIDEO_BTTV_CARDS_TEA5757_READ 	 0x00004921
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_SET_PLL  	 0x00004922
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_BTTV_READ 	 0x00004923
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_BTTV_CLOSE 	 0x00004924
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_BTTV_IOCTL 	 0x00004925
#define DRIVERS_MEDIA_VIDEO_BTTV_DRIVER_VBI_READ 	 0x00004926
#define DRIVERS_MEDIA_VIDEO_ZR36120_ZORAN_CLOSE  	 0x00004927
#define DRIVERS_MEDIA_VIDEO_ZR36120_VBI_CLOSE    	 0x00004928

#define DRIVERS_MESSAGE_FUSION_MPTBASE_MAKEIOCREADY 	 0x00004a01
#define DRIVERS_MESSAGE_FUSION_MPTBASE_SENDIOCINIT 	 0x00004a02
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_DOWNLOADBOOT 	 0x00004a03
#define DRIVERS_MESSAGE_FUSION_MPTBASE_KICKSTART 	 0x00004a04
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_DIAG_RESET 	 0x00004a05
#define DRIVERS_MESSAGE_FUSION_MPTBASE_SENDIOCRESET 	 0x00004a06
#define DRIVERS_MESSAGE_FUSION_MPTBASE_WAITFORDOORBELLACK 	 0x00004a07
#define DRIVERS_MESSAGE_FUSION_MPTBASE_WAITFORDOORBELLINT 	 0x00004a08
#define DRIVERS_MESSAGE_FUSION_MPTBASE_MPT_CONFIG 	 0x00004a09
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_RELEASE 	 0x00004a0a
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_TASKMGMT_BH 	 0x00004a0b
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DO_RAID 	 0x00004a0c
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DO_CMD 	 0x00004a0d
#define DRIVERS_MESSAGE_FUSION_MPTSCSIH_MPTSCSIH_DOMAINVALIDATION 	 0x00004a0e
#define DRIVERS_MESSAGE_FUSION_MPTLAN_MPT_LAN_CLOSE 	 0x00004a0f
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_DELETE_CONTROLLER 	 0x00004a10
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_RELEASE_DEVICE 	 0x00004a11
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_WAIT_MESSAGE 	 0x00004a12
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_RESET_CONTROLLER 	 0x00004a13
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_STATUS_GET 	 0x00004a14
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_INIT_OUTBOUND_Q 	 0x00004a15
#define DRIVERS_MESSAGE_I2O_I2O_CORE_I2O_POST_WAIT_MEM 	 0x00004a16
#define DRIVERS_MESSAGE_I2O_I2O_BLOCK_I2O_BLOCK_EXIT 	 0x00004a17

#define DRIVERS_MTD_CHIPS_AMD_FLASH_READ_ONE_CHIP 	 0x00004b01
#define DRIVERS_MTD_CHIPS_AMD_FLASH_WRITE_ONE_WORD 	 0x00004b02
#define DRIVERS_MTD_CHIPS_AMD_FLASH_ERASE_ONE_BLOCK 	 0x00004b03
#define DRIVERS_MTD_CHIPS_AMD_FLASH_AMD_FLASH_SYNC 	 0x00004b04
#define DRIVERS_MTD_CHIPS_CFI_PROBE_CFI_UDELAY   	 0x00004b05
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_CFI_UDELAY 	 0x00004b06
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_READ_ONECHIP 	 0x00004b07
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_WRITE_ONEWORD 	 0x00004b08
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_DO_ERASE_ONEBLOCK 	 0x00004b09
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0002_CFI_AMDSTD_SYNC 	 0x00004b0a
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_CFI_UDELAY 	 0x00004b0b
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_READ_ONECHIP 	 0x00004b0c
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_WRITE_ONEWORD 	 0x00004b0d
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_WRITE_BUFFER 	 0x00004b0e
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_ERASE_ONEBLOCK 	 0x00004b0f
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_CFI_INTELEXT_SYNC 	 0x00004b10
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_LOCK_ONEBLOCK 	 0x00004b11
#define DRIVERS_MTD_CHIPS_CFI_CMDSET_0001_DO_UNLOCK_ONEBLOCK 	 0x00004b12
#define DRIVERS_MTD_CHIPS_GEN_PROBE_CFI_UDELAY   	 0x00004b13
#define DRIVERS_MTD_CHIPS_JEDEC_PROBE_CFI_UDELAY 	 0x00004b14
#define DRIVERS_MTD_CHIPS_SHARP_CFI_UDELAY       	 0x00004b15
#define DRIVERS_MTD_CHIPS_SHARP_SHARP_WAIT       	 0x00004b16
#define DRIVERS_MTD_CHIPS_SHARP_SHARP_DO_WAIT_FOR_READY 	 0x00004b17
#define DRIVERS_MTD_DEVICES_DOC1000_FLASHCARD_WRITE 	 0x00004b18
#define DRIVERS_MTD_DEVICES_DOC2000__DOC_WAITREADY 	 0x00004b19
#define DRIVERS_MTD_DEVICES_BLKMTD_QUEUE_PAGE_WRITE 	 0x00004b1a
#define DRIVERS_MTD_DEVICES_BLKMTD_BLKMTD_SYNC   	 0x00004b1b
#define DRIVERS_MTD_NAND_NAND_NAND_READ_ECC      	 0x00004b1c
#define DRIVERS_MTD_NAND_NAND_NAND_READ_OOB      	 0x00004b1d
#define DRIVERS_MTD_NAND_NAND_NAND_WRITE_ECC     	 0x00004b1e
#define DRIVERS_MTD_NAND_NAND_NAND_WRITE_OOB     	 0x00004b1f
#define DRIVERS_MTD_NAND_NAND_NAND_WRITEV        	 0x00004b20
#define DRIVERS_MTD_NAND_NAND_NAND_ERASE         	 0x00004b21
#define DRIVERS_MTD_NAND_NAND_NAND_SYNC          	 0x00004b22
#define DRIVERS_MTD_MTDCONCAT_CONCAT_DEV_ERASE   	 0x00004b23
#define DRIVERS_MTD_MTDCHAR_MTD_IOCTL            	 0x00004b24
#define DRIVERS_MTD_MTDBLOCK_ERASE_WRITE         	 0x00004b25
#define DRIVERS_MTD_MTDBLOCK_MTDBLOCK_THREAD     	 0x00004b26

#define DRIVERS_NET_APPLETALK_COPS_COPS_RESET    	 0x00004c01
#define DRIVERS_NET_APPLETALK_COPS_COPS_NODEID   	 0x00004c02
#define DRIVERS_NET_APPLETALK_LTPC_LTPC_CLEANUP  	 0x00004c03
#define DRIVERS_NET_E100_E100_MAIN_E100_SELFTEST 	 0x00004c04
#define DRIVERS_NET_E100_E100_MAIN_E100_ETHTOOL_LED_BLINK 	 0x00004c05
#define DRIVERS_NET_E100_E100_PROC_SET_LED       	 0x00004c06
#define DRIVERS_NET_E100_E100_TEST_E100_RUN_DIAG 	 0x00004c07
#define DRIVERS_NET_E100_E100_TEST_E100_DIAG_CONFIG_LOOPBACK 	 0x00004c08
#define DRIVERS_NET_E1000_E1000_HW_E1000_RESET_HW 	 0x00004c09
#define DRIVERS_NET_E1000_E1000_HW_E1000_INIT_HW 	 0x00004c0a
#define DRIVERS_NET_E1000_E1000_HW_E1000_SETUP_FIBER_LINK 	 0x00004c0b
#define DRIVERS_NET_E1000_E1000_HW_E1000_PHY_FORCE_SPEED_DUPLEX 	 0x00004c0c
#define DRIVERS_NET_E1000_E1000_HW_E1000_WAIT_AUTONEG 	 0x00004c0d
#define DRIVERS_NET_E1000_E1000_HW_E1000_PHY_HW_RESET 	 0x00004c0e
#define DRIVERS_NET_E1000_E1000_ETHTOOL_E1000_ETHTOOL_LED_BLINK 	 0x00004c0f
#define DRIVERS_NET_IRDA_IRDA_USB_WAIT_MS        	 0x00004c10
#define DRIVERS_NET_PCMCIA_XIRC2PS_CS_BUSY_LOOP  	 0x00004c11
#define DRIVERS_NET_TOKENRING_IBMTR_TOK_INIT_CARD 	 0x00004c12
#define DRIVERS_NET_TOKENRING_IBMTR_TOK_OPEN     	 0x00004c13
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_INIT 	 0x00004c14
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_OPEN 	 0x00004c15
#define DRIVERS_NET_TOKENRING_OLYMPIC_OLYMPIC_CLOSE 	 0x00004c16
#define DRIVERS_NET_TOKENRING_LANSTREAMER_STREAMER_RESET 	 0x00004c17
#define DRIVERS_NET_TOKENRING_3C359_XL_HW_RESET  	 0x00004c18
#define DRIVERS_NET_TOKENRING_3C359_XL_OPEN_HW   	 0x00004c19
#define DRIVERS_NET_TOKENRING_3C359_XL_CLOSE     	 0x00004c1a
#define DRIVERS_NET_WAN_8253X_8253XSYN_SAB8253X_CLOSES 	 0x00004c1b
#define DRIVERS_NET_WAN_8253X_8253XTTY_SAB8253X_CLOSE 	 0x00004c1c
#define DRIVERS_NET_WAN_8253X_8253XCHR_SAB8253X_BLOCK_TIL_READYC 	 0x00004c1d
#define DRIVERS_NET_WAN_8253X_8253XUTL_SAB8253X_BLOCK_TIL_READY 	 0x00004c1e
#define DRIVERS_NET_WAN_8253X_8253XUTL_SAB8253X_WAIT_UNTIL_SENT 	 0x00004c1f
#define DRIVERS_NET_WAN_FARSYNC_FST_ISSUE_CMD    	 0x00004c20
#define DRIVERS_NET_WAN_CYCX_DRV_DELAY_CYCX      	 0x00004c21
#define DRIVERS_NET_WIRELESS_ORINOCO_PLX_ORINOCO_PLX_EXIT 	 0x00004c22
#define DRIVERS_NET_SUNGEM_GEM_SHUTDOWN          	 0x00004c23
#define DRIVERS_NET_SIS900_SIS900_MII_PROBE      	 0x00004c24
#define DRIVERS_NET_NS83820_NS83820_DO_RESET     	 0x00004c25
#define DRIVERS_NET_NS83820_NS83820_RUN_BIST     	 0x00004c26
#define DRIVERS_NET_NS83820_NS83820_INIT_ONE     	 0x00004c27
#define DRIVERS_NET_SB1000_NICEDELAY             	 0x00004c28
#define DRIVERS_NET_SB1000_CARD_WAIT_FOR_BUSY_CLEAR 	 0x00004c29
#define DRIVERS_NET_SB1000_CARD_WAIT_FOR_READY   	 0x00004c2a
#define DRIVERS_NET_HP100_HP100_DOWN_VG_LINK     	 0x00004c2b
#define DRIVERS_NET_HP100_HP100_LOGIN_TO_VG_HUB  	 0x00004c2c
#define DRIVERS_NET_PPP_GENERIC_PPP_READ         	 0x00004c2d
#define DRIVERS_NET_8139CP_CP_RESET_HW           	 0x00004c2e
#define DRIVERS_NET_CS89X0_RESET_CHIP            	 0x00004c2f
#define DRIVERS_NET_TUN_TUN_CHR_READV            	 0x00004c30
#define DRIVERS_NET_HAMRADIO_BAYCOM_EPP_EPP_OPEN 	 0x00004c31

#define DRIVERS_PARPORT_IEEE1284_PARPORT_WAIT_PERIPHERAL 	 0x00004d01
#define DRIVERS_PARPORT_IEEE1284_OPS_PARPORT_IEEE1284_WRITE_COMPAT 	 0x00004d02
#define DRIVERS_PARPORT_IEEE1284_OPS_PARPORT_IEEE1284_ECP_READ_DATA 	 0x00004d03
#define DRIVERS_PARPORT_DAISY_PARPORT_DAISY_INIT 	 0x00004d04

#define DRIVERS_PCI_PCI_PCI_SET_POWER_STATE      	 0x00004e01
#define DRIVERS_PCI_PCI_PCI_POOL_ALLOC           	 0x00004e02

#define DRIVERS_PCMCIA_DS_INIT_PCMCIA_DS         	 0x00004f01
#define DRIVERS_PCMCIA_CS_CS_SLEEP               	 0x00004f02
#define DRIVERS_PCMCIA_I82365_TEST_IRQ           	 0x00004f03

#define DRIVERS_SCSI_AACRAID_COMMSUP_AAC_COMMAND_THREAD 	 0x00005001
#define DRIVERS_SCSI_AACRAID_RX_RX_SYNC_CMD      	 0x00005002
#define DRIVERS_SCSI_AACRAID_RX_AAC_RX_INIT      	 0x00005003
#define DRIVERS_SCSI_AACRAID_SA_SA_SYNC_CMD      	 0x00005004
#define DRIVERS_SCSI_AACRAID_SA_AAC_SA_INIT      	 0x00005005
#define DRIVERS_SCSI_SCSI_SCSI_ALLOCATE_DEVICE   	 0x00005006
#define DRIVERS_SCSI_SCSI_ERROR_SCSI_BLOCK_WHEN_PROCESSING_ERRORS 	 0x00005007
#define DRIVERS_SCSI_DPT_I2O_ADPT_I2O_POST_WAIT  	 0x00005008
#define DRIVERS_SCSI_DPT_I2O_ADPT_IOCTL          	 0x00005009
#define DRIVERS_SCSI_PPA_PPA_DETECT              	 0x0000500a
#define DRIVERS_SCSI_PPA_PPA_INIT                	 0x0000500b
#define DRIVERS_SCSI_PPA_PPA_COMMAND             	 0x0000500c
#define DRIVERS_SCSI_IMM_IMM_DETECT              	 0x0000500d
#define DRIVERS_SCSI_IMM_IMM_INIT                	 0x0000500e
#define DRIVERS_SCSI_IMM_IMM_COMMAND             	 0x0000500f
#define DRIVERS_SCSI_CPQFCTSINIT_CPQFCTS_DETECT  	 0x00005010
#define DRIVERS_SCSI_ST_TEST_READY               	 0x00005011
#define DRIVERS_SCSI_OSST_OSST_WAIT_READY        	 0x00005012
#define DRIVERS_SCSI_OSST_OSST_WAIT_FOR_MEDIUM   	 0x00005013
#define DRIVERS_SCSI_OSST_OSST_WAIT_FRAME        	 0x00005014
#define DRIVERS_SCSI_OSST_OSST_READ_BACK_BUFFER_AND_REWRITE 	 0x00005015
#define DRIVERS_SCSI_OSST_OSST_REPOSITION_AND_RETRY 	 0x00005016
#define DRIVERS_SCSI_SD_SD_INIT_ONEDISK          	 0x00005017
#define DRIVERS_SCSI_SG_SG_OPEN                  	 0x00005018
#define DRIVERS_SCSI_SG_SG_READ                  	 0x00005019
#define DRIVERS_SCSI_SG_SG_IOCTL                 	 0x0000501a

#define DRIVERS_SOUND_CS4281_CS4281M_DELAYUS     	 0x00005101
#define DRIVERS_SOUND_CS4281_CS4281M_DRAIN_ADC   	 0x00005102
#define DRIVERS_SOUND_CS4281_CS4281M_DRAIN_DAC   	 0x00005103
#define DRIVERS_SOUND_CS4281_CS4281M_CS4281_MIDI_RELEASE 	 0x00005104
#define DRIVERS_SOUND_EMU10K1_ECARD_EMU10K1_ECARD_INIT 	 0x00005105
#define DRIVERS_SOUND_MIDI_SYNTH_MIDI_SYNTH_LOAD_PATCH 	 0x00005106
#define DRIVERS_SOUND_CS4232_SLEEP               	 0x00005107
#define DRIVERS_SOUND_ALI5455_DRAIN_DAC          	 0x00005108
#define DRIVERS_SOUND_ALI5455_DRAIN_SPDIFOUT     	 0x00005109
#define DRIVERS_SOUND_ALI5455_ALI_READ           	 0x0000510a
#define DRIVERS_SOUND_ALI5455_ALI_WRITE          	 0x0000510b
#define DRIVERS_SOUND_ALI5455_ALI_OPEN           	 0x0000510c
#define DRIVERS_SOUND_ALI5455_ALI_OPEN_MIXDEV    	 0x0000510d
#define DRIVERS_SOUND_ALI5455_ALI_AC97_PROBE_AND_POWERUP 	 0x0000510e
#define DRIVERS_SOUND_ALI5455_ALI_AC97_RANDOM_INIT_STUFF 	 0x0000510f
#define DRIVERS_SOUND_SSCAPE_SLEEP               	 0x00005110
#define DRIVERS_SOUND_MAD16_WAIT_MS              	 0x00005111
#define DRIVERS_SOUND_MAUI_MAUI_WAIT             	 0x00005112
#define DRIVERS_SOUND_SGALAXY_SLEEP              	 0x00005113
#define DRIVERS_SOUND_ACI_BUSY_WAIT              	 0x00005114
#define DRIVERS_SOUND_AWE_WAVE_AWE_WAIT          	 0x00005115
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DO_READ 	 0x00005116
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DO_WRITE 	 0x00005117
#define DRIVERS_SOUND_VIA82CXXX_AUDIO_VIA_DSP_DRAIN_PLAYBACK 	 0x00005118
#define DRIVERS_SOUND_YMFPCI_YMFPCI_CODEC_READY  	 0x00005119
#define DRIVERS_SOUND_YMFPCI_YMF_WAIT_DAC        	 0x0000511a
#define DRIVERS_SOUND_YMFPCI_YMF_READ            	 0x0000511b
#define DRIVERS_SOUND_YMFPCI_YMF_WRITE           	 0x0000511c
#define DRIVERS_SOUND_I810_AUDIO_DRAIN_DAC       	 0x0000511d
#define DRIVERS_SOUND_I810_AUDIO_I810_READ       	 0x0000511e
#define DRIVERS_SOUND_I810_AUDIO_I810_WRITE      	 0x0000511f
#define DRIVERS_SOUND_I810_AUDIO_I810_OPEN       	 0x00005120
#define DRIVERS_SOUND_I810_AUDIO_I810_OPEN_MIXDEV 	 0x00005121
#define DRIVERS_SOUND_I810_AUDIO_I810_AC97_PROBE_AND_POWERUP 	 0x00005122
#define DRIVERS_SOUND_I810_AUDIO_I810_AC97_RANDOM_INIT_STUFF 	 0x00005123
#define DRIVERS_SOUND_SONICVIBES_WAIT_MS         	 0x00005124
#define DRIVERS_SOUND_SONICVIBES_DRAIN_DAC       	 0x00005125
#define DRIVERS_SOUND_SONICVIBES_SV_READ         	 0x00005126
#define DRIVERS_SOUND_SONICVIBES_SV_WRITE        	 0x00005127
#define DRIVERS_SOUND_SONICVIBES_SV_OPEN         	 0x00005128
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_READ    	 0x00005129
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_WRITE   	 0x0000512a
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_OPEN    	 0x0000512b
#define DRIVERS_SOUND_SONICVIBES_SV_MIDI_RELEASE 	 0x0000512c
#define DRIVERS_SOUND_SONICVIBES_SV_DMFM_OPEN    	 0x0000512d
#define DRIVERS_SOUND_CMPCI_DRAIN_DAC            	 0x0000512e
#define DRIVERS_SOUND_CMPCI_CM_MIDI_READ         	 0x0000512f
#define DRIVERS_SOUND_CMPCI_CM_MIDI_WRITE        	 0x00005130
#define DRIVERS_SOUND_CMPCI_CM_MIDI_RELEASE      	 0x00005131
#define DRIVERS_SOUND_ES1370_WAIT_MS             	 0x00005132
#define DRIVERS_SOUND_ES1370_WRCODEC             	 0x00005133
#define DRIVERS_SOUND_ES1370_DRAIN_DAC1          	 0x00005134
#define DRIVERS_SOUND_ES1370_DRAIN_DAC2          	 0x00005135
#define DRIVERS_SOUND_ES1370_ES1370_READ         	 0x00005136
#define DRIVERS_SOUND_ES1370_ES1370_WRITE        	 0x00005137
#define DRIVERS_SOUND_ES1370_ES1370_OPEN         	 0x00005138
#define DRIVERS_SOUND_ES1370_ES1370_WRITE_DAC    	 0x00005139
#define DRIVERS_SOUND_ES1370_ES1370_OPEN_DAC     	 0x0000513a
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_READ    	 0x0000513b
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_WRITE   	 0x0000513c
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_OPEN    	 0x0000513d
#define DRIVERS_SOUND_ES1370_ES1370_MIDI_RELEASE 	 0x0000513e
#define DRIVERS_SOUND_ES1371_WAIT_MS             	 0x0000513f
#define DRIVERS_SOUND_ES1371_DRAIN_DAC1          	 0x00005140
#define DRIVERS_SOUND_ES1371_DRAIN_DAC2          	 0x00005141
#define DRIVERS_SOUND_ES1371_ES1371_READ         	 0x00005142
#define DRIVERS_SOUND_ES1371_ES1371_WRITE        	 0x00005143
#define DRIVERS_SOUND_ES1371_ES1371_OPEN         	 0x00005144
#define DRIVERS_SOUND_ES1371_ES1371_WRITE_DAC    	 0x00005145
#define DRIVERS_SOUND_ES1371_ES1371_OPEN_DAC     	 0x00005146
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_READ    	 0x00005147
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_WRITE   	 0x00005148
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_OPEN    	 0x00005149
#define DRIVERS_SOUND_ES1371_ES1371_MIDI_RELEASE 	 0x0000514a
#define DRIVERS_SOUND_ES1371_ES1371_PROBE        	 0x0000514b
#define DRIVERS_SOUND_ESSSOLO1_WAIT_MS           	 0x0000514c
#define DRIVERS_SOUND_ESSSOLO1_DRAIN_DAC         	 0x0000514d
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_READ        	 0x0000514e
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_WRITE       	 0x0000514f
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_OPEN        	 0x00005150
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_READ   	 0x00005151
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_WRITE  	 0x00005152
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_OPEN   	 0x00005153
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_MIDI_RELEASE 	 0x00005154
#define DRIVERS_SOUND_ESSSOLO1_SOLO1_DMFM_OPEN   	 0x00005155
#define DRIVERS_SOUND_CS46XX_DRAIN_DAC           	 0x00005156
#define DRIVERS_SOUND_CS46XX_CS_MIDI_RELEASE     	 0x00005157
#define DRIVERS_SOUND_CS46XX_CS_READ             	 0x00005158
#define DRIVERS_SOUND_CS46XX_CS_WRITE            	 0x00005159
#define DRIVERS_SOUND_CS46XX_CS_HARDWARE_INIT    	 0x0000515a
#define DRIVERS_SOUND_MAESTRO_DRAIN_DAC          	 0x0000515b
#define DRIVERS_SOUND_MAESTRO_CHECK_SUSPEND      	 0x0000515c
#define DRIVERS_SOUND_MAESTRO3_DRAIN_DAC         	 0x0000515d
#define DRIVERS_SOUND_MAESTRO3_M3_CODEC_RESET    	 0x0000515e
#define DRIVERS_SOUND_MAESTRO3_CHECK_SUSPEND     	 0x0000515f
#define DRIVERS_SOUND_FORTE_FORTE_CHANNEL_DRAIN  	 0x00005160
#define DRIVERS_SOUND_FORTE_FORTE_DSP_WRITE      	 0x00005161
#define DRIVERS_SOUND_FORTE_FORTE_DSP_READ       	 0x00005162
#define DRIVERS_SOUND_TRIDENT_WAIT_MS            	 0x00005163
#define DRIVERS_SOUND_TRIDENT_DRAIN_DAC          	 0x00005164
#define DRIVERS_SOUND_RME96XX_RME96XX_OPEN       	 0x00005165
#define DRIVERS_SOUND_BTAUDIO_BTAUDIO_DSP_READ   	 0x00005166

#define DRIVERS_TELEPHONY_IXJ_IXJ_WINK           	 0x00005201
#define DRIVERS_TELEPHONY_IXJ_IXJ_REGISTER       	 0x00005202
#define DRIVERS_TELEPHONY_IXJ_IXJ_HOOKSTATE      	 0x00005203
#define DRIVERS_TELEPHONY_IXJ_IXJ_RING           	 0x00005204
#define DRIVERS_TELEPHONY_IXJ_IXJ_RELEASE        	 0x00005205
#define DRIVERS_TELEPHONY_IXJ_IXJ_WRITE_CIDCW    	 0x00005206
#define DRIVERS_TELEPHONY_IXJ_IXJ_IOCTL          	 0x00005207
#define DRIVERS_TELEPHONY_IXJ_IXJ_LINETEST       	 0x00005208
#define DRIVERS_TELEPHONY_IXJ_IXJ_SELFPROBE      	 0x00005209

#define DRIVERS_USB_SERIAL_USBSERIAL_WAIT_MS     	 0x00005301

#define DRIVERS_USB_SERIAL_VISOR_WAIT_MS         	 0x00005a01
#define DRIVERS_USB_SERIAL_IPAQ_WAIT_MS          	 0x00005302
#define DRIVERS_USB_SERIAL_WHITEHEAT_WAIT_MS     	 0x00005a02
#define DRIVERS_USB_SERIAL_FTDI_SIO_WAIT_MS      	 0x00005303
#define DRIVERS_USB_SERIAL_KEYSPAN_PDA_WAIT_MS   	 0x00005a03
#define DRIVERS_USB_SERIAL_KEYSPAN_WAIT_MS       	 0x00005304
#define DRIVERS_USB_SERIAL_OMNINET_WAIT_MS       	 0x00005a04
#define DRIVERS_USB_SERIAL_DIGI_ACCELEPORT_WAIT_MS 	 0x00005305
#define DRIVERS_USB_SERIAL_DIGI_ACCELEPORT_COND_WAIT_INTERRUPTIBLE_TIMEOUT_IRQRESTORE 	 0x00005306
#define DRIVERS_USB_SERIAL_BELKIN_SA_WAIT_MS     	 0x00005a05
#define DRIVERS_USB_SERIAL_EMPEG_WAIT_MS         	 0x00005307
#define DRIVERS_USB_SERIAL_MCT_U232_WAIT_MS      	 0x00005a06
#define DRIVERS_USB_SERIAL_IO_EDGEPORT_WAIT_MS   	 0x00005308
#define DRIVERS_USB_SERIAL_IO_TI_WAIT_MS         	 0x00005a07
#define DRIVERS_USB_SERIAL_PL2303_WAIT_MS        	 0x00005309
#define DRIVERS_USB_SERIAL_CYBERJACK_WAIT_MS     	 0x00005a08
#define DRIVERS_USB_SERIAL_IR_USB_WAIT_MS        	 0x0000530a
#define DRIVERS_USB_SERIAL_KL5KUSB105_WAIT_MS    	 0x00005a09

#define DRIVERS_USB_STORAGE_SCSIGLUE_WAIT_MS     	 0x00005401
#define DRIVERS_USB_STORAGE_PROTOCOL_WAIT_MS     	 0x00005a0a
#define DRIVERS_USB_STORAGE_TRANSPORT_WAIT_MS    	 0x00005402
#define DRIVERS_USB_STORAGE_TRANSPORT_USB_STOR_CB_RESET 	 0x00005403
#define DRIVERS_USB_STORAGE_TRANSPORT_USB_STOR_BULK_RESET 	 0x00005404
#define DRIVERS_USB_STORAGE_USB_WAIT_MS          	 0x00005a0b
#define DRIVERS_USB_STORAGE_INITIALIZERS_WAIT_MS 	 0x00005405
#define DRIVERS_USB_STORAGE_SHUTTLE_USBAT_WAIT_MS 	 0x00005a0c
#define DRIVERS_USB_STORAGE_SDDR09_WAIT_MS       	 0x00005406
#define DRIVERS_USB_STORAGE_SDDR55_WAIT_MS       	 0x00005a0d
#define DRIVERS_USB_STORAGE_FREECOM_WAIT_MS      	 0x00005407
#define DRIVERS_USB_STORAGE_DPCM_WAIT_MS         	 0x00005a0e
#define DRIVERS_USB_STORAGE_ISD200_WAIT_MS       	 0x00005408
#define DRIVERS_USB_STORAGE_DATAFAB_WAIT_MS      	 0x00005a0f
#define DRIVERS_USB_STORAGE_JUMPSHOT_WAIT_MS     	 0x00005409

#define DRIVERS_USB_USB_WAIT_MS                  	 0x00005501
#define DRIVERS_USB_USB_USB_START_WAIT_URB       	 0x00005502

#define DRIVERS_USB_USB_DEBUG_WAIT_MS            	 0x00005601

#define DRIVERS_USB_HUB_WAIT_MS                  	 0x00005701
#define DRIVERS_USB_HUB_USB_HUB_THREAD           	 0x00005702

#define DRIVERS_USB_DEVIO_WAIT_MS                	 0x00005801
#define DRIVERS_USB_DEVIO_PROC_REAPURB           	 0x00005802

#define DRIVERS_USB_INODE_WAIT_MS                	 0x00005901
#define DRIVERS_USB_DRIVERS_WAIT_MS              	 0x00005a10
#define DRIVERS_USB_DEVICES_WAIT_MS              	 0x00005a11
#define DRIVERS_USB_HCD_WAIT_MS                  	 0x00005a12
#define DRIVERS_USB_EHCI_HCD_WAIT_MS             	 0x00005a13
#define DRIVERS_USB_UHCI_WAIT_MS                 	 0x00005a14
#define DRIVERS_USB_UHCI_UHCI_UNLINK_URB         	 0x00005a15
#define DRIVERS_USB_USB_OHCI_WAIT_MS             	 0x00005a16
#define DRIVERS_USB_USB_OHCI_SOHCI_UNLINK_URB    	 0x00005a17
#define DRIVERS_USB_USB_OHCI_SOHCI_FREE_DEV      	 0x00005a18
#define DRIVERS_USB_HID_CORE_WAIT_MS             	 0x00005a19
#define DRIVERS_USB_HIDDEV_WAIT_MS               	 0x00005a1a
#define DRIVERS_USB_HIDDEV_HIDDEV_READ           	 0x00005a1b
#define DRIVERS_USB_HID_INPUT_WAIT_MS            	 0x00005a1c
#define DRIVERS_USB_AIPTEK_WAIT_MS               	 0x00005a1d
#define DRIVERS_USB_WACOM_WAIT_MS                	 0x00005a1e
#define DRIVERS_USB_SCANNER_WAIT_MS              	 0x00005a1f
#define DRIVERS_USB_ACM_WAIT_MS                  	 0x00005a20
#define DRIVERS_USB_PRINTER_WAIT_MS              	 0x00005a21
#define DRIVERS_USB_PRINTER_USBLP_WRITE          	 0x00005a22
#define DRIVERS_USB_AUDIO_WAIT_MS                	 0x00005a23
#define DRIVERS_USB_AUDIO_USBIN_STOP             	 0x00005a24
#define DRIVERS_USB_AUDIO_USBOUT_STOP            	 0x00005a25
#define DRIVERS_USB_AUDIO_DRAIN_OUT              	 0x00005a26
#define DRIVERS_USB_AUDIO_USB_AUDIO_READ         	 0x00005a27
#define DRIVERS_USB_AUDIO_USB_AUDIO_WRITE        	 0x00005a28
#define DRIVERS_USB_AUDIO_USB_AUDIO_OPEN         	 0x00005a29
#define DRIVERS_USB_EMI26_WAIT_MS                	 0x00005a2a
#define DRIVERS_USB_USB_MIDI_WAIT_MS             	 0x00005a2b
#define DRIVERS_USB_USB_MIDI_USB_MIDI_READ       	 0x00005a2c
#define DRIVERS_USB_USB_MIDI_USB_MIDI_OPEN       	 0x00005a2d
#define DRIVERS_USB_IBMCAM_WAIT_MS               	 0x00005a2e
#define DRIVERS_USB_USBVIDEO_WAIT_MS             	 0x00005a2f
#define DRIVERS_USB_ULTRACAM_WAIT_MS             	 0x00005a30
#define DRIVERS_USB_PWC_IF_WAIT_MS               	 0x00005a31
#define DRIVERS_USB_PWC_IF_PWC_VIDEO_READ        	 0x00005a32
#define DRIVERS_USB_PWC_IF_PWC_VIDEO_IOCTL       	 0x00005a33
#define DRIVERS_USB_PWC_IF_USB_PWC_DISCONNECT    	 0x00005a34
#define DRIVERS_USB_PWC_MISC_WAIT_MS             	 0x00005a35
#define DRIVERS_USB_PWC_CTRL_WAIT_MS             	 0x00005a36
#define DRIVERS_USB_PWC_UNCOMPRESS_WAIT_MS       	 0x00005a37
#define DRIVERS_USB_DC2XX_WAIT_MS                	 0x00005a38
#define DRIVERS_USB_MDC800_WAIT_MS               	 0x00005a39
#define DRIVERS_USB_MDC800_MDC800_USB_WAITFORIRQ 	 0x00005a3a
#define DRIVERS_USB_MDC800_MDC800_DEVICE_READ    	 0x00005a3b
#define DRIVERS_USB_MDC800_MDC800_DEVICE_WRITE   	 0x00005a3c
#define DRIVERS_USB_USS720_WAIT_MS               	 0x00005a3d
#define DRIVERS_USB_USS720_CHANGE_MODE           	 0x00005a3e
#define DRIVERS_USB_DABUSB_WAIT_MS               	 0x00005a3f
#define DRIVERS_USB_DABUSB_DABUSB_OPEN           	 0x00005a40
#define DRIVERS_USB_VICAM_WAIT_MS                	 0x00005a41
#define DRIVERS_USB_VICAM_SYNCHRONIZE            	 0x00005a42
#define DRIVERS_USB_OV511_WAIT_MS                	 0x00005a43
#define DRIVERS_USB_OV511_INIT_OV_SENSOR         	 0x00005a44
#define DRIVERS_USB_OV511_OV51X_V4L1_IOCTL_INTERNAL 	 0x00005a45
#define DRIVERS_USB_OV511_OV51X_V4L1_READ        	 0x00005a46
#define DRIVERS_USB_OV511_OV7XX0_CONFIGURE       	 0x00005a47
#define DRIVERS_USB_SE401_WAIT_MS                	 0x00005a48
#define DRIVERS_USB_SE401_SE401_NEWFRAME         	 0x00005a49
#define DRIVERS_USB_STV680_WAIT_MS               	 0x00005a4a
#define DRIVERS_USB_STV680_STV680_NEWFRAME       	 0x00005a4b
#define DRIVERS_USB_PEGASUS_WAIT_MS              	 0x00005a4c
#define DRIVERS_USB_PEGASUS_GET_REGISTERS        	 0x00005a4d
#define DRIVERS_USB_PEGASUS_SET_REGISTERS        	 0x00005a4e
#define DRIVERS_USB_PEGASUS_SET_REGISTER         	 0x00005a4f
#define DRIVERS_USB_RTL8150_WAIT_MS              	 0x00005a50
#define DRIVERS_USB_CATC_WAIT_MS                 	 0x00005a51
#define DRIVERS_USB_KAWETH_WAIT_MS               	 0x00005a52
#define DRIVERS_USB_KAWETH_KAWETH_DISCONNECT     	 0x00005a53
#define DRIVERS_USB_KAWETH_USB_START_WAIT_URB    	 0x00005a54
#define DRIVERS_USB_CDCETHER_WAIT_MS             	 0x00005a55
#define DRIVERS_USB_RIO500_WAIT_MS               	 0x00005a56
#define DRIVERS_USB_TIGLUSB_WAIT_MS              	 0x00005a57
#define DRIVERS_USB_TIGLUSB_TIGLUSB_OPEN         	 0x00005a58
#define DRIVERS_USB_DSBR100_WAIT_MS              	 0x00005a59
#define DRIVERS_USB_MICROTEK_WAIT_MS             	 0x00005a5a
#define DRIVERS_USB_HPUSBSCSI_WAIT_MS            	 0x00005a5b
#define DRIVERS_USB_USBNET_WAIT_MS               	 0x00005a5c
#define DRIVERS_USB_USBNET_USBNET_STOP           	 0x00005a5d
#define DRIVERS_USB_AUERSWALD_WAIT_MS            	 0x00005a5e
#define DRIVERS_USB_AUERSWALD_AUERCHAIN_START_WAIT_URB 	 0x00005a5f
#define DRIVERS_USB_AUERSWALD_AUERCHAR_READ      	 0x00005a60
#define DRIVERS_USB_AUERSWALD_AUERCHAR_WRITE     	 0x00005a61
#define DRIVERS_USB_BRLVGER_WAIT_MS              	 0x00005a62
#define DRIVERS_USB_BRLVGER_BRLVGER_OPEN         	 0x00005a63
#define DRIVERS_USB_BRLVGER_BRLVGER_READ         	 0x00005a64
#define DRIVERS_USB_USBLCD_WAIT_MS               	 0x00005a65

#define MM_FILEMAP_TRUNCATE_LIST_PAGES           	 0x00005b01
#define MM_FILEMAP_INVALIDATE_LIST_PAGES2        	 0x00005b02
#define MM_FILEMAP____WAIT_ON_PAGE               	 0x00005b03
#define MM_FILEMAP___LOCK_PAGE                   	 0x00005b04
#define MM_VMSCAN_SWAP_OUT                       	 0x00005b05
#define MM_VMSCAN_SHRINK_CACHE                   	 0x00005b06
#define MM_VMSCAN_KSWAPD_BALANCE_PGDAT           	 0x00005b07
#define MM_VMSCAN_KSWAPD                         	 0x00005b08
#define MM_SWAPFILE_TRY_TO_UNUSE                 	 0x00005b09

#define FS_CODA_PSDEV_CODA_PSDEV_READ            	 0x00005c01
#define FS_CODA_UPCALL_CODA_WAITFOR_UPCALL       	 0x00005c02

#define FS_DEVFS_BASE_WAIT_FOR_DEVFSD_FINISHED   	 0x00005d01
#define FS_DEVFS_BASE_DEVFS_D_REVALIDATE_WAIT    	 0x00005d02
#define FS_DEVFS_BASE_DEVFSD_READ                	 0x00005d03

#define FS_EXT3_IOCTL_EXT3_IOCTL                 	 0x00005e01

#define FS_HFS_BALLOC_HFS_RELINQUISH             	 0x00005f01
#define FS_HFS_BDELETE_HFS_RELINQUISH            	 0x00005f02
#define FS_HFS_BFIND_HFS_RELINQUISH              	 0x00005f03
#define FS_HFS_BINS_DEL_HFS_RELINQUISH           	 0x00005f04
#define FS_HFS_BINSERT_HFS_RELINQUISH            	 0x00005f05
#define FS_HFS_BITMAP_HFS_RELINQUISH             	 0x00005f06
#define FS_HFS_BITOPS_HFS_RELINQUISH             	 0x00005f07
#define FS_HFS_BNODE_HFS_RELINQUISH              	 0x00005f08
#define FS_HFS_BREC_HFS_RELINQUISH               	 0x00005f09
#define FS_HFS_BTREE_HFS_RELINQUISH              	 0x00005f0a
#define FS_HFS_CATALOG_HFS_RELINQUISH            	 0x00005f0b
#define FS_HFS_DIR_HFS_RELINQUISH                	 0x00005f0c
#define FS_HFS_DIR_CAP_HFS_RELINQUISH            	 0x00005f0d
#define FS_HFS_DIR_DBL_HFS_RELINQUISH            	 0x00005f0e
#define FS_HFS_DIR_NAT_HFS_RELINQUISH            	 0x00005f0f
#define FS_HFS_EXTENT_HFS_RELINQUISH             	 0x00005f10
#define FS_HFS_FILE_HFS_RELINQUISH               	 0x00005f11
#define FS_HFS_FILE_CAP_HFS_RELINQUISH           	 0x00005f12
#define FS_HFS_FILE_HDR_HFS_RELINQUISH           	 0x00005f13
#define FS_HFS_INODE_HFS_RELINQUISH              	 0x00005f14
#define FS_HFS_MDB_HFS_RELINQUISH                	 0x00005f15
#define FS_HFS_PART_TBL_HFS_RELINQUISH           	 0x00005f16
#define FS_HFS_STRING_HFS_RELINQUISH             	 0x00005f17
#define FS_HFS_SUPER_HFS_RELINQUISH              	 0x00005f18
#define FS_HFS_SYSDEP_HFS_RELINQUISH             	 0x00005f19
#define FS_HFS_TRANS_HFS_RELINQUISH              	 0x00005f1a

#define FS_INTERMEZZO_PRESTO_PRESTO_GET_PERMIT   	 0x00006001
#define FS_INTERMEZZO_PRESTO_IZO_REVOKE_PERMIT   	 0x00006002
#define FS_INTERMEZZO_PSDEV_LENTO_WAITFOR_UPCALL 	 0x00006003

#define FS_JBD_COMMIT_JOURNAL_COMMIT_TRANSACTION 	 0x00006101

#define FS_JFFS_INTREP_FLASH_ERASE_REGION        	 0x00006201
#define FS_JFFS_INTREP_JFFS_GARBAGE_COLLECT_THREAD 	 0x00006202

#define FS_JFFS2_NODEMGMT_JFFS2_RESERVE_SPACE    	 0x00006301
#define FS_JFFS2_NODEMGMT_JFFS2_DO_RESERVE_SPACE 	 0x00006302
#define FS_JFFS2_ERASE_JFFS2_ERASE_PENDING_BLOCKS 	 0x00006303
#define FS_JFFS2_BACKGROUND_JFFS2_GARBAGE_COLLECT_THREAD 	 0x00006304

#define FS_LOCKD_CLNTPROC_NLMCLNT_ALLOC_CALL     	 0x00006401

#define FS_NCPFS_SOCK_DO_NCP_RPC_CALL            	 0x00006501
#define FS_NCPFS_SOCK_DO_TCP_RCV                 	 0x00006502
#define FS_NCPFS_SYMLINK_NCP_SYMLINK_READPAGE    	 0x00006503

#define FS_NFS_DIR_FIND_DIRENT                   	 0x00006601
#define FS_NFS_DIR_READDIR_SEARCH_PAGECACHE      	 0x00006602
#define FS_NFS_DIR_NFS_DO_FILLDIR                	 0x00006603
#define FS_NFS_INODE_NFS_WAIT_ON_INODE           	 0x00006604
#define FS_NFS_PAGELIST_NFS_WAIT_ON_REQUEST      	 0x00006605
#define FS_NFS_NFS3PROC_NFS3_RPC_WRAPPER         	 0x00006606

#define FS_NFSD_VFS_NFSD_WRITE                   	 0x00006701

#define FS_NTFS_DIR_NTFS_ALLOCATE_INDEX_BLOCK    	 0x00006801

#define FS_REISERFS_INODE_REISERFS_GET_BLOCK     	 0x00006901
#define FS_REISERFS_FIX_NODE_GET_MEM_FOR_VIRTUAL_NODE 	 0x00006902
#define FS_REISERFS_JOURNAL_REISERFS_WAIT_ON_WRITE_BLOCK 	 0x00006903

#define FS_SMBFS_PROC_SMB_PROC_READDIR_LONG      	 0x00006a01
#define FS_SMBFS_SOCK_SMB_RECEIVE_POLL           	 0x00006a02

#define FS_BUFFER___WAIT_ON_BUFFER               	 0x00006b01
#define FS_BUFFER_KUPDATE                        	 0x00006b02

#define FS_PIPE_PIPE_WAIT                        	 0x00006c01

#define FS_NAMEI_DO_FOLLOW_LINK                  	 0x00006d01

#define FS_SELECT_DO_SELECT                      	 0x00006e01
#define FS_SELECT_DO_POLL                        	 0x00006e02

#define FS_LOCKS_INTERRUPTIBLE_SLEEP_ON_LOCKED   	 0x00006f01

#define FS_INODE___WAIT_ON_INODE                 	 0x00007001

#define FS_IOBUF_KIOBUF_WAIT_FOR_IO              	 0x00007101

#define FS_DQUOT___WAIT_ON_DQUOT                 	 0x00007201
#define FS_DQUOT___WAIT_DQUOT_UNUSED             	 0x00007202
#define FS_DQUOT_DQGET                           	 0x00007203

#define NET_APPLETALK_AARP_AARP_PROBE_NETWORK    	 0x00007301
#define NET_APPLETALK_AARP_AARP_PROXY_PROBE_NETWORK 	 0x00007302

#define NET_ATM_SIGNALING_MODIFY_QOS             	 0x00007401
#define NET_ATM_SIGNALING_SIGD_ENQ2              	 0x00007402
#define NET_ATM_SVC_SVC_DISCONNECT               	 0x00007403
#define NET_ATM_SVC_SVC_BIND                     	 0x00007404
#define NET_ATM_SVC_SVC_CONNECT                  	 0x00007405
#define NET_ATM_SVC_SVC_LISTEN                   	 0x00007406
#define NET_ATM_SVC_SVC_ACCEPT                   	 0x00007407
#define NET_ATM_SVC_SVC_CHANGE_QOS               	 0x00007408
#define NET_ATM_COMMON_ALLOC_TX                  	 0x00007409
#define NET_ATM_COMMON_ATM_RECVMSG               	 0x0000740a
#define NET_ATM_COMMON_ATM_SENDMSG               	 0x0000740b

#define NET_BLUETOOTH_BNEP_CORE_BNEP_SESSION     	 0x00007501
#define NET_BLUETOOTH_AF_BLUETOOTH_BLUEZ_SOCK_W4_CONNECT 	 0x00007502
#define NET_BLUETOOTH_HCI_CORE___HCI_REQUEST     	 0x00007503
#define NET_BLUETOOTH_L2CAP_L2CAP_SOCK_ACCEPT    	 0x00007504
#define NET_BLUETOOTH_SCO_SCO_SOCK_ACCEPT        	 0x00007505

#define NET_CORE_SOCK_SOCK_WAIT_FOR_WMEM         	 0x00007601
#define NET_CORE_SOCK___LOCK_SOCK                	 0x00007602
#define NET_CORE_DATAGRAM_WAIT_FOR_PACKET        	 0x00007603
#define NET_CORE_DEV_DEV_CLOSE                   	 0x00007604
#define NET_CORE_DEV_UNREGISTER_NETDEVICE        	 0x00007605
#define NET_CORE_NETFILTER_NF_UNREGISTER_SOCKOPT 	 0x00007606
#define NET_CORE_PKTGEN_INJECT                   	 0x00007607

#define NET_DECNET_AF_DECNET_DN_CONNECT          	 0x00007701
#define NET_DECNET_AF_DECNET_DN_WAIT_ACCEPT      	 0x00007702
#define NET_DECNET_AF_DECNET_DN_ACCEPT           	 0x00007703
#define NET_DECNET_AF_DECNET_DN_WAIT_RUN         	 0x00007704
#define NET_DECNET_AF_DECNET_DN_RECVMSG          	 0x00007705
#define NET_DECNET_AF_DECNET_DN_SENDMSG          	 0x00007706
#define NET_DECNET_DN_NSP_OUT_DN_ALLOC_SEND_SKB  	 0x00007707

#define NET_IPV4_TCP_WAIT_FOR_TCP_CONNECT        	 0x00007801
#define NET_IPV4_TCP_WAIT_FOR_TCP_MEMORY         	 0x00007802
#define NET_IPV4_TCP_TCP_DATA_WAIT               	 0x00007803
#define NET_IPV4_TCP_TCP_CLOSE                   	 0x00007804
#define NET_IPV4_TCP_WAIT_FOR_CONNECT            	 0x00007805
#define NET_IPV4_TCP_IPV4_TCP_LISTEN_WLOCK       	 0x00007806
#define NET_IPV4_AF_INET_INET_WAIT_FOR_CONNECT   	 0x00007807
#define NET_IPV4_NETFILTER_IP_CONNTRACK_CORE_IP_CONNTRACK_CLEANUP 	 0x00007808

#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_BLOCK_TIL_READY 	 0x00007901
#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_CLOSE 	 0x00007902
#define NET_IRDA_IRCOMM_IRCOMM_TTY_IRCOMM_TTY_WAIT_UNTIL_SENT 	 0x00007903
#define NET_IRDA_IRNET_IRNET_PPP_IRNET_CTRL_READ 	 0x00007904

#define NET_NETLINK_AF_NETLINK_NETLINK_TABLE_GRAB 	 0x00007a01
#define NET_NETLINK_AF_NETLINK_NETLINK_UNICAST   	 0x00007a02

#define NET_SUNRPC_SCHED___RPC_EXECUTE           	 0x00007b01
#define NET_SUNRPC_SCHED___RPC_SCHEDULE          	 0x00007b02
#define NET_SUNRPC_SCHED_RPCIOD                  	 0x00007b03
#define NET_SUNRPC_SVCSOCK_SVC_RECV              	 0x00007b04

#define NET_UNIX_AF_UNIX_UNIX_WAIT_FOR_PEER      	 0x00007c01
#define NET_UNIX_AF_UNIX_UNIX_STREAM_DATA_WAIT   	 0x00007c02

#define IPC_MSG_SYS_MSGSND                       	 0x00007d01
#define IPC_MSG_SYS_MSGRCV                       	 0x00007d02

#define IPC_SEM_SYS_SEMOP                        	 0x00007e01

#define LIB_RWSEM_RWSEM_DOWN_FAILED_COMMON       	 0x00007f01

#define ARCH_I386_KERNEL_PROCESS_CPU_IDLE        	 0x00008001
#define ARCH_I386_KERNEL_SEMAPHORE___DOWN        	 0x00008002
#define ARCH_I386_KERNEL_SEMAPHORE___DOWN_INTERRUPTIBLE 	 0x00008003
#define ARCH_I386_KERNEL_SIGNAL_SYS_SIGSUSPEND   	 0x00008004
#define ARCH_I386_KERNEL_SIGNAL_SYS_RT_SIGSUSPEND 	 0x00008005
#define ARCH_I386_KERNEL_SIGNAL_DO_SIGNAL        	 0x00008006
#define ARCH_I386_KERNEL_PTRACE_SYSCALL_TRACE    	 0x00008007
#define ARCH_I386_KERNEL_SYS_I386_SYS_PAUSE      	 0x00008008
#define ARCH_I386_KERNEL_APM_APM_MAINLOOP        	 0x00008009
#define ARCH_I386_KERNEL_APM_DO_READ             	 0x0000800a
#define ARCH_I386_KERNEL_APM_DO_IOCTL            	 0x0000800b
#define ARCH_I386_KERNEL_APM_APM_EXIT            	 0x0000800c

#define EVENT_BLOCK					 0x01000000

#define EVENT_SYSTEM					 0x04000000
#define EVENT_SYSTEM_CLOCKTICK				 0x04010000

#define EVENT_PROCESS                 		 	 0x05000000
#define EVENT_PROCESS_NEW                                0x05010000
#define EVENT_PROCESS_END                                0x05020000
#define EVENT_PROCESS_END_USER                           0x05020100
#define EVENT_PROCESS_END_SYSTEM                         0x05020200

#define EVENT_UNBLOCK					 0x02000000
#define EVENT_UNBLOCK_NONPREEMPTIVE			 0x02030000
#define EVENT_UNBLOCK_PREEMPTIVE			 0x02040000
#define EVENT_UNBLOCK_TIMER				 0x02050000

#define EVENT_YIELD					 0x03000000
#define EVENT_YIELD_SYSTEM          			 0x03010000
#define EVENT_YIELD_SYSTEM_IMMEDIATE			 0x03010100
#define EVENT_YIELD_SYSTEM_PAUSE    			 0x03010200
#define EVENT_YIELD_USER				 0x03020000
#define EVENT_YIELD_USER_EDF				 0x03020100

#endif
