/* -------------- scheduler management interface functions -------------- */

#include <stdio.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <sched.h>
#include <sys/time.h>
#include <sys/resource.h>

int bossa_connect(int parent, int child, int argc, char *argv);
int bossa_attach_info(int parent);
int bossa_print(char *s, int sz);

#define BOSSA_ID_NUM 0xCE
#define IOCTL_CONNECT        _IOWR(BOSSA_ID_NUM, 0, int)
#define IOCTL_PRINT          _IOR(BOSSA_ID_NUM, 1, int)
#define IOCTL_ATTACH_INFO    _IOWR(BOSSA_ID_NUM, 2, int)
#define IOCTL_SCHED	     _IOWR(BOSSA_ID_NUM, 3, int)
#define IOCTL_NBSCHED        _IOWR(BOSSA_ID_NUM, 4, int)
#define IOCTL_NAMES          _IOR(BOSSA_ID_NUM, 5, int)
#define IOCTL_DISCONNECT     _IOWR(BOSSA_ID_NUM, 6, int)
#define IOCTL_CONNECT_ROOT   _IOWR(BOSSA_ID_NUM, 7, int)
#define BOSSA_DEVICE_NAME "bossa"

struct dev_bossa_attach_info_struct {
  int parent;
  int parent_attach_argc;
  char parent_attach_argv[300];
};

struct dev_bossa_attach_info_struct attach_info_data;

struct dev_bossa_connect_struct {
  int parent;
  int child;
  int data[10];
};

struct dev_bossa_disconnect_struct {
  int tgt;
};

struct dev_bossa_print_struct {
  char *s;
  int sz;
};

int bossa_attach_info(int parent) {
  attach_info_data.parent = parent;
  {
    int fd, res;
    fd = open("/dev/bossa/" BOSSA_DEVICE_NAME, O_RDWR);
    res = ioctl(fd,IOCTL_ATTACH_INFO,(char *)&attach_info_data);
    if (res) perror("bossa_attach_info");
    close(fd);
    return res;
  }
}

int bossa_connect(int parent, int child, int argc, char *argv) {
  struct dev_bossa_connect_struct _data;
  int i;
  _data.parent = parent;
  _data.child = child;
  for(i=0; i!=argc; i++) {
    printf("%s: ",argv);
    argv = argv + 30;
    scanf("%d",&(_data.data[i]));
  }
  {
    int fd, res;
    fd = open("/dev/bossa/" BOSSA_DEVICE_NAME, O_RDWR);
    res = ioctl(fd,IOCTL_CONNECT,(char *)&_data);
    if (res) perror("bossa_connect");
    close(fd);
    return res;
  }
}

int bossa_disconnect(int tgt) {
  struct dev_bossa_disconnect_struct _data;
  int i;
  _data.tgt = tgt;
  {
    int fd, res;
    fd = open("/dev/bossa/" BOSSA_DEVICE_NAME, O_RDWR);
    res = ioctl(fd,IOCTL_DISCONNECT,(char *)&_data);
    if (res) perror("bossa_disconnect");
    close(fd);
    return res;
  }
}

int bossa_print(char *s, int sz) {
  struct dev_bossa_print_struct _data;
  _data.s = s;
  _data.sz = sz;
  {
    int fd, res;
    fd = open("/dev/bossa/" BOSSA_DEVICE_NAME, O_RDONLY);
    res = ioctl(fd,IOCTL_PRINT,(char *)&_data);
    if (res) perror("bossa_print");
    close(fd);
    return res;
  }
}

int main() {
  char b[1000];
  char com;
  int parent, child, tgt, ct;
  char *help =
    "\nCommand: (use the scheduler number)\n"
    "  c <P> <C> \tconnect parent scheduler P to child scheduler C\n"\
    "  d <S>\t\tdisconnect scheduler S\n  l\t\tlist available schedulers\n"\
    "  h \t\tprint this help menu\n  q\t\tquit\n\n";
  
  printf("Available schedulers:\n");
  bossa_print(b, 900);
  printf(b);
  printf("%s\n",help);
  while(1) {
    printf("> ");
    if (scanf("%c",&com) == EOF) exit(0);
    switch (com) {
    case 'c':
      ct = scanf("%d %d",&parent,&child);
      if (ct == 2) {
	if (bossa_attach_info(parent) != -1) {
	  bossa_connect(parent,child,
			attach_info_data.parent_attach_argc,
			attach_info_data.parent_attach_argv);
	} else {
	  printf("invalid arguments: no change\n");
	}
      } else {
	printf("invalid arguments: no change\n");
      }
      break;
    case 'd':
      ct = scanf("%d",&tgt);
      if (ct == 1) {
	bossa_disconnect(tgt);
      } else {
	printf("invalid arguments: no change\n");
      }
      break;
    case 'l':
      printf("Available schedulers:\n");
      bossa_print(b, 900);
      printf(b);
      break;
    case 'h':
    case '?':
      printf("%s\n",help);
      break;
    case 'q':
      exit(0);
    case '\n': break;
    default:
      printf("invalid command: no change\n");
    }
    while(getchar() != '\n');
  }
}
